@@ -94,7 +94,6 @@ class SideNav(hg.ASIDE):
                                                         " bx--side-nav__menu-item--current",
                                                     ),
                                                 ),
-                                                role="none",
                                             ),
                                         ),
                                         _class="bx--side-nav__menu",
@@ -154,13 +153,11 @@ class SideNav(hg.ASIDE):
                             _class="bx--assistive-text",
                         ),
                         _class="bx--side-nav__toggle",
-                        role="button",
                         onclick="setBreadCookie('sidenav-hidden', getBreadCookie('sidenav-hidden', 'false') != 'true');",
                     ),
                     _class="bx--side-nav__footer",
                 ),
                 _class="bx--side-nav__navigation",
-                role="navigation",
             ),
             **kwargs,
         )
